// **************************************************************************
// ROOT macro: plot_total.c
// Plots the figures of total pair production cross section data. 
// There is one figure (now in png format, it can be modified) per element.
// -	cross section data of EPICS2014 (Z: 1-100) 
// -	cross section data of Livermore (Z: 1-99)   
// -	comparison of cross section data between Livermore and EPICS2014 (Z: 1-99) 
// The generated figures are saved in the corresponding directory:
// -	plots/total/comparison
// -	plots/total/epics2017
// -	plots/total/livermore

// Authors: Zhuxin LI @CENBG,France
// 2019.12.09
// **************************************************************************
TString sInt(Int_t number)
  {
    stringstream ss;
    ss << number;
	TString ts = ss.str();
    return ts;
  }
TString sDouble(Double_t number)
  {
    stringstream ss;
	ss << number;
    TString ts = ss.str();
    return ts;
  }

	

void plot_comparison(std::vector<double>& Z,std::vector<double>& y_epics2017_ratioMax, std::vector<double>& y_livermore_ratioMax,
std::vector<double>& y_epics2017_average, std::vector<double>& y_livermore_average, string& Process)
{
	gROOT->Reset();
	
	TString title;
	title = "Maximal relative difference for " + Process ;
	string name = Process;
	string name1 = Process + "1";
	TCanvas* mycanvas = new TCanvas(name.c_str(),"Conversion of electrons and gammas",300, 0, 400,400);
	printf("-------------For process %s --------------\n",Process.c_str());
	for(int i=0;i<Z.size(); i++)
	{
		printf("Z = %.9e %.9e %.9e %.9e %.9e\n", Z[i], y_epics2017_ratioMax[i],y_livermore_ratioMax[i],
		y_epics2017_average[i], y_livermore_average[i] );
	}		
		// mycanvas->SetGrid();
		
		// mycanvas->SetLeftMargin(0.15);
		gPad->SetGrid();
		// gPad->SetLogx();
		// gPad->SetLogy();
		gPad->SetBottomMargin(0.15);
		gPad->SetLeftMargin(0.15);
		// gPad->SetLeftMargin(0.01);
		//gPad->SetLogy();
	
		
		auto mg = new TMultiGraph();
		TGraph *epics2017 = new TGraph(Z.size(),Z.data(),y_epics2017_ratioMax.data());		
		TGraph *livermore = new TGraph(Z.size(),Z.data(),y_livermore_ratioMax.data());

		
		
		epics2017->SetMarkerStyle(24);  // red point
		epics2017->SetMarkerSize(1.2);
		epics2017->SetMarkerColor(kRed);
		//epics2017->SetLineWidth(2);
		epics2017->SetLineColor(kRed);	
		mg->Add(epics2017);
		
		livermore->SetMarkerStyle(21);  // red point
		livermore->SetMarkerSize(1.);
		livermore->SetMarkerColor(kBlue);
		//livermore->SetLineWidth(2);
		livermore->SetLineColor(kBlue);	
		mg->Add(livermore);
		
		
		// // //set graph parameters of livermore
		
		
		mg->Draw("AP");
				
		// mg->SetTitle(title);		
		mg->GetXaxis()->SetTitle("Atomic number Z");
		mg->GetYaxis()->SetTitle("Maximal relative difference (%)");
		
		// mg->GetXaxis()->SetTitleSize(0.05);
		// mg->GetYaxis()->SetTitleSize(0.05);
		
		// mg->GetXaxis()->SetLabelSize(0.05);
		// mg->GetYaxis()->SetLabelSize(0.05);
		mg->GetXaxis()->SetTitleOffset(1.5);
		mg->GetYaxis()->SetTitleOffset(2);

		
		mg->GetXaxis()->CenterTitle();
		mg->GetYaxis()->CenterTitle();
		
		TGaxis *axisX = new TGaxis(gPad->GetUxmin(),gPad->GetUymax(),
		gPad->GetUxmax(), gPad->GetUymax(),
		mg->GetXaxis()->GetXmin(),
		mg->GetXaxis()->GetXmax(), 510,"U-");
		// axis->SetLineColor(kRed);
		// axis->SetLabelColor(kRed);
		axisX->Draw("");
		
		
		TGaxis *axisY = new TGaxis(gPad->GetUxmax(),gPad->GetUymin(),
		gPad->GetUxmax(), gPad->GetUymax(),
		mg->GetYaxis()->GetXmin(),
		mg->GetYaxis()->GetXmax(), 510,"U+");
		// axis->SetLineColor(kRed);
		// axis->SetLabelColor(kRed);
		axisY->Draw();
   
		
		TLegend* leg = new TLegend(0.65,0.7,0.9,0.9);
		// TLegend* leg1 = new TLegend(0.5,0.7,0.9,0.9);
		// leg1->SetTextAlign(12);
		// leg1->SetFillColor(0);
		// leg1->SetFillStyle(0);		
		leg->SetTextSize(0.04);
		
		TString rname11 = "EPICS2017";
		TString rname111 = "Livermore";
		
		
		leg->AddEntry(epics2017,rname11);
		leg->AddEntry(livermore,rname111);
		
		TString figureName = Process + ".png";
		mycanvas->Print("plots/RatioMax/"+figureName);
		// delete mycanvas;
		// mycanvas = NULL;
		// mycanvas->Close();
		
		
		//********************************************
		TCanvas* mycanvas1 = new TCanvas(name1.c_str(),"Conversion of electrons and gammas",900, 0, 400,400);
		// mycanvas->cd(2);
		gPad->SetGrid();
		// gPad->SetLogx();
		// gPad->SetLogy();
		gPad->SetBottomMargin(0.15);
		gPad->SetLeftMargin(0.15);
		
		auto mg1 = new TMultiGraph();
		TGraph *Ratio1 = new TGraph(Z.size(),Z.data(),y_epics2017_average.data());
		TGraph *Ratio2 = new TGraph(Z.size(),Z.data(),y_livermore_average.data());
		
		Ratio1->SetMarkerStyle(24);  // red point
		Ratio1->SetMarkerSize(1.2);
		Ratio1->SetMarkerColor(kRed);
		//Ratio1->SetLineWidth(2);
		Ratio1->SetLineColor(kRed);	
		mg1->Add(Ratio1);
		
		Ratio2->SetMarkerStyle(21);  // red point
		Ratio2->SetMarkerSize(1.);
		Ratio2->SetMarkerColor(kBlue);
		//Ratio2->SetLineWidth(2);
		Ratio2->SetLineColor(kBlue);	
		mg1->Add(Ratio2);
		
		
		// // //set graph parameters of livermore
		
		
		mg1->Draw("AP");
		
		TString title1 = "Absolute average difference for " + Process;
	
		
		// mg1->SetTitle(title1);		
		mg1->GetXaxis()->SetTitle("Atomic number Z");
		mg1->GetYaxis()->SetTitle("Mean absolute relative difference (%)");
		
		
		
		// mg1->GetXaxis()->SetTitleSize(0.05);
		// mg1->GetYaxis()->SetTitleSize(0.05);
		
		// mg1->GetXaxis()->SetLabelSize(0.05);
		// mg1->GetYaxis()->SetLabelSize(0.05);
		
		mg1->GetXaxis()->SetTitleOffset(1.5);
		mg1->GetYaxis()->SetTitleOffset(2);
		
		mg1->GetXaxis()->CenterTitle();
		mg1->GetYaxis()->CenterTitle();
		
		TGaxis *axisX1 = new TGaxis(gPad->GetUxmin(),gPad->GetUymax(),
		gPad->GetUxmax(), gPad->GetUymax(),
		mg1->GetXaxis()->GetXmin(),
		mg1->GetXaxis()->GetXmax(), 510,"U-");
		// axis->SetLineColor(kRed);
		// axis->SetLabelColor(kRed);
		axisX1->Draw("");
		
		
		TGaxis *axisY1 = new TGaxis(gPad->GetUxmax(),gPad->GetUymin(),
		gPad->GetUxmax(), gPad->GetUymax(),
		mg1->GetYaxis()->GetXmin(),
		mg1->GetYaxis()->GetXmax(), 510,"U+");
		// axis->SetLineColor(kRed);
		// axis->SetLabelColor(kRed);
		axisY1->Draw();
		
		TLegend* leg1 = new TLegend(0.12,0.15,0.35,0.3);
		// TLegend* leg1 = new TLegend(0.5,0.7,0.9,0.9);
		// leg1->SetTextAlign(12);
		// leg1->SetFillColor(0);
		// leg1->SetFillStyle(0);		
		leg1->SetTextSize(0.04);
		
	
		leg1->AddEntry(Ratio1,rname11);
		leg1->AddEntry(Ratio2,rname111);
		
		//leg1->DrawClone("Same");
		// leg1->Draw();
		
		mycanvas1->Print("plots/Average/"+figureName);
		// delete mycanvas;
		// mycanvas = NULL;
		// mycanvas->Close();
		
		
}


//for the publication, instead of using 101 and 102 for water and Bone,we use 3.3 and 4.4
//In addition need to use another symbols to represent them
void plot_comparison_publication(std::vector<double>& Z,std::vector<double>& y_epics2017_ratioMax, std::vector<double>& y_livermore_ratioMax,
std::vector<double>& y_epics2017_average, std::vector<double>& y_livermore_average, string& Process)
{
	gROOT->Reset();
	
	TString title;
	title = "Maximal relative difference for " + Process ;
	string name = Process;
	string name1 = Process + "1";
	TCanvas* mycanvas = new TCanvas(name.c_str(),"Conversion of electrons and gammas",300, 0, 400,400);
	// printf("-------------For process %s --------------\n",Process.c_str());
	// for(int i=0;i<ZZ.size(); i++)
	// {
		// printf("Z = %.9e %.9e %.9e %.9e %.9e\n", ZZ[i], y_epics2017_ratioMax[i],y_livermore_ratioMax[i],
		// y_epics2017_average[i], y_livermore_average[i] );
	// }

	std::vector<double> Z_2;
	std::vector<double> y_epics2017_ratioMax_2; 
	std::vector<double> y_livermore_ratioMax_2;
	std::vector<double> y_epics2017_average_2;
	std::vector<double> y_livermore_average_2;

	for(int i=0;i<Z.size(); i++)
	{
		printf("Z = %.9e %.9e %.9e %.9e %.9e\n", Z[i], y_epics2017_ratioMax[i],y_livermore_ratioMax[i],
		y_epics2017_average[i], y_livermore_average[i]);
		
		if(Z[i] ==3.3 || Z[i] ==4.4)
		{
			Z_2.push_back(Z[i]);
			y_epics2017_ratioMax_2.push_back(y_epics2017_ratioMax[i]);
			y_livermore_ratioMax_2.push_back(y_livermore_ratioMax[i]);
			y_epics2017_average_2.push_back(y_epics2017_average[i]);
			y_livermore_average_2.push_back(y_livermore_average[i]);
		}
		
		
	}
	
		// mycanvas->SetGrid();
		
		// mycanvas->SetLeftMargin(0.15);
		gPad->SetGrid();
		// gPad->SetLogx();
		// gPad->SetLogy();
		gPad->SetBottomMargin(0.15);
		gPad->SetLeftMargin(0.15);
		// gPad->SetLeftMargin(0.01);
		//gPad->SetLogy();
	
		
		auto mg = new TMultiGraph();
		TGraph *epics2017 = new TGraph(Z.size(),Z.data(),y_epics2017_ratioMax.data());		
		TGraph *livermore = new TGraph(Z.size(),Z.data(),y_livermore_ratioMax.data());
		
		TGraph *epics2017_2 = new TGraph(Z_2.size(),Z_2.data(),y_epics2017_ratioMax_2.data());		
		TGraph *livermore_2 = new TGraph(Z_2.size(),Z_2.data(),y_livermore_ratioMax_2.data());
		
		
		
		epics2017->SetMarkerStyle(24);  // red point
		epics2017->SetMarkerSize(1.2);
		epics2017->SetMarkerColor(kRed);
		//epics2017->SetLineWidth(2);
		epics2017->SetLineColor(kRed);	
		mg->Add(epics2017);
		
		livermore->SetMarkerStyle(21);  // red point
		livermore->SetMarkerSize(1.);
		livermore->SetMarkerColor(kBlue);
		//livermore->SetLineWidth(2);
		livermore->SetLineColor(kBlue);	
		mg->Add(livermore);
		
		
		
		epics2017_2->SetMarkerStyle(2);  // red point
		epics2017_2->SetMarkerSize(2.5);
		epics2017_2->SetMarkerColor(kRed);
		//epics2017->SetLineWidth(2);
		epics2017_2->SetLineColor(kRed);	
		mg->Add(epics2017_2);
		
		livermore_2->SetMarkerStyle(5);  // red point
		livermore_2->SetMarkerSize(2.5);
		livermore_2->SetMarkerColor(kBlue);
		//livermore->SetLineWidth(2);
		livermore_2->SetLineColor(kBlue);	
		mg->Add(livermore_2);
		
		
		// // //set graph parameters of livermore
		
		
		mg->Draw("AP");
				
		// mg->SetTitle(title);		
		mg->GetXaxis()->SetTitle("Atomic number Z");
		mg->GetYaxis()->SetTitle("Maximal relative difference (%)");
		
		// mg->GetXaxis()->SetTitleSize(0.05);
		// mg->GetYaxis()->SetTitleSize(0.05);
		
		// mg->GetXaxis()->SetLabelSize(0.05);
		// mg->GetYaxis()->SetLabelSize(0.05);
		mg->GetXaxis()->SetTitleOffset(1.5);
		mg->GetYaxis()->SetTitleOffset(2);

		
		mg->GetXaxis()->CenterTitle();
		mg->GetYaxis()->CenterTitle();
		
		TGaxis *axisX = new TGaxis(gPad->GetUxmin(),gPad->GetUymax(),
		gPad->GetUxmax(), gPad->GetUymax(),
		mg->GetXaxis()->GetXmin(),
		mg->GetXaxis()->GetXmax(), 510,"U-");
		// axis->SetLineColor(kRed);
		// axis->SetLabelColor(kRed);
		axisX->Draw("");
		
		
		TGaxis *axisY = new TGaxis(gPad->GetUxmax(),gPad->GetUymin(),
		gPad->GetUxmax(), gPad->GetUymax(),
		mg->GetYaxis()->GetXmin(),
		mg->GetYaxis()->GetXmax(), 510,"U+");
		// axis->SetLineColor(kRed);
		// axis->SetLabelColor(kRed);
		axisY->Draw();
   
		
		TLegend* leg = new TLegend(0.65,0.7,0.9,0.9);
		// TLegend* leg1 = new TLegend(0.5,0.7,0.9,0.9);
		// leg1->SetTextAlign(12);
		// leg1->SetFillColor(0);
		// leg1->SetFillStyle(0);		
		leg->SetTextSize(0.04);
		
		TString rname11 = "EPICS2017";
		TString rname111 = "Livermore";
		
		
		leg->AddEntry(epics2017,rname11);
		leg->AddEntry(livermore,rname111);
		
		TString figureName = Process + ".png";
		mycanvas->Print("plots/RatioMax/"+figureName);
		// delete mycanvas;
		// mycanvas = NULL;
		// mycanvas->Close();
		
		
		//********************************************
		TCanvas* mycanvas1 = new TCanvas(name1.c_str(),"Conversion of electrons and gammas",900, 0, 400,400);
		// mycanvas->cd(2);
		gPad->SetGrid();
		// gPad->SetLogx();
		// gPad->SetLogy();
		gPad->SetBottomMargin(0.15);
		gPad->SetLeftMargin(0.15);
		
		auto mg1 = new TMultiGraph();
		TGraph *Ratio1 = new TGraph(Z.size(),Z.data(),y_epics2017_average.data());
		TGraph *Ratio2 = new TGraph(Z.size(),Z.data(),y_livermore_average.data());
		
		TGraph *Ratio1_2 = new TGraph(Z_2.size(),Z_2.data(),y_epics2017_average_2.data());
		TGraph *Ratio2_2 = new TGraph(Z_2.size(),Z_2.data(),y_livermore_average_2.data());
		
		Ratio1->SetMarkerStyle(24);  // red point
		Ratio1->SetMarkerSize(1.2);
		Ratio1->SetMarkerColor(kRed);
		//Ratio1->SetLineWidth(2);
		Ratio1->SetLineColor(kRed);	
		mg1->Add(Ratio1);
		
		Ratio2->SetMarkerStyle(21);  // red point
		Ratio2->SetMarkerSize(1.);
		Ratio2->SetMarkerColor(kBlue);
		//Ratio2->SetLineWidth(2);
		Ratio2->SetLineColor(kBlue);	
		mg1->Add(Ratio2);
		
		
		Ratio1_2->SetMarkerStyle(2);  // red point
		Ratio1_2->SetMarkerSize(2.5);
		Ratio1_2->SetMarkerColor(kRed);
		//Ratio1->SetLineWidth(2);
		Ratio1_2->SetLineColor(kRed);	
		mg1->Add(Ratio1_2);
		
		Ratio2_2->SetMarkerStyle(5);  // red point
		Ratio2_2->SetMarkerSize(2.5);
		Ratio2_2->SetMarkerColor(kBlue);
		//Ratio2->SetLineWidth(2);
		Ratio2_2->SetLineColor(kBlue);	
		mg1->Add(Ratio2_2);
		
		
		// // //set graph parameters of livermore
		
		
		mg1->Draw("AP");
		
		TString title1 = "Absolute average difference for " + Process;
	
		
		// mg1->SetTitle(title1);		
		mg1->GetXaxis()->SetTitle("Atomic number Z");
		mg1->GetYaxis()->SetTitle("Mean absolute relative difference (%)");
		
		
		
		// mg1->GetXaxis()->SetTitleSize(0.05);
		// mg1->GetYaxis()->SetTitleSize(0.05);
		
		// mg1->GetXaxis()->SetLabelSize(0.05);
		// mg1->GetYaxis()->SetLabelSize(0.05);
		
		mg1->GetXaxis()->SetTitleOffset(1.5);
		mg1->GetYaxis()->SetTitleOffset(2);
		
		mg1->GetXaxis()->CenterTitle();
		mg1->GetYaxis()->CenterTitle();
		
		TGaxis *axisX1 = new TGaxis(gPad->GetUxmin(),gPad->GetUymax(),
		gPad->GetUxmax(), gPad->GetUymax(),
		mg1->GetXaxis()->GetXmin(),
		mg1->GetXaxis()->GetXmax(), 510,"U-");
		// axis->SetLineColor(kRed);
		// axis->SetLabelColor(kRed);
		axisX1->Draw("");
		
		
		TGaxis *axisY1 = new TGaxis(gPad->GetUxmax(),gPad->GetUymin(),
		gPad->GetUxmax(), gPad->GetUymax(),
		mg1->GetYaxis()->GetXmin(),
		mg1->GetYaxis()->GetXmax(), 510,"U+");
		// axis->SetLineColor(kRed);
		// axis->SetLabelColor(kRed);
		axisY1->Draw();
		
		TLegend* leg1 = new TLegend(0.12,0.15,0.35,0.3);
		// TLegend* leg1 = new TLegend(0.5,0.7,0.9,0.9);
		// leg1->SetTextAlign(12);
		// leg1->SetFillColor(0);
		// leg1->SetFillStyle(0);		
		leg1->SetTextSize(0.04);
		
	
		leg1->AddEntry(Ratio1,rname11);
		leg1->AddEntry(Ratio2,rname111);
		
		//leg1->DrawClone("Same");
		// leg1->Draw();
		
		mycanvas1->Print("plots/Average/"+figureName);
		// delete mycanvas;
		// mycanvas = NULL;
		// mycanvas->Close();
		
		
}



void plot_ratioMax_Average(){
	
	gROOT->Reset();	
	gSystem->Exec("mkdir -p plots");
	gSystem->Exec("mkdir -p plots/RatioMax");
	gSystem->Exec("mkdir -p plots/Average");
	


	
	double MaterialsAtomicNum[13] = {4, 6, 13, 14, 26, 32, 47, 55, 79, 82, 92, 3.3, 4.4};
	string Materials[20] = {"Be", "C", "Al", "Si", "Fe", "Ge", "Ag", "Cs", "Au", "Pb", "U", "Water", "BONE_COMPACT_ICRU"};
	string Processes[5] = {"gamma conversion","Compton effect","photoelectric", "Rayleigh scattering", "total"};
	vector<double> Z;
	for(int i=0; i<13; ++i)
	{
		Z.push_back(MaterialsAtomicNum[i]);
	}
	
	
	vector<double> epics2017_total_ratioMax;
	vector<double> epics2017_total_average;
	
	vector<double> epics2017_pair_ratioMax;
	vector<double> epics2017_pair_average;
	
	vector<double> epics2017_compt_ratioMax;
	vector<double> epics2017_compt_average;
	
	vector<double> epics2017_phot_ratioMax;
	vector<double> epics2017_phot_average;
	
	vector<double> epics2017_rayl_ratioMax;
	vector<double> epics2017_rayl_average;
	
	//***********************************************
	vector<double> livermore_total_ratioMax;
	vector<double> livermore_total_average;
	
	vector<double> livermore_pair_ratioMax;
	vector<double> livermore_pair_average;
	
	vector<double> livermore_compt_ratioMax;
	vector<double> livermore_compt_average;
	
	vector<double> livermore_phot_ratioMax;
	vector<double> livermore_phot_average;
	
	vector<double> livermore_rayl_ratioMax;
	vector<double> livermore_rayl_average;

	double P[10] = {0};	
	
	std::ostringstream ost;
	ost <<"./ratioMax_Average_epics2017_final.dat"; //
	std::ifstream fin(ost.str().c_str());
	
	for(int i = 0; i<13;i++) // 1612 lines 
	{
		
		fin >>P[0]>>P[1]>>P[2]>>P[3]>>P[4]>>P[5]>>P[6]>>P[7]>>P[8]>>P[9];
		
		
		epics2017_pair_ratioMax.push_back(P[0]);
		epics2017_pair_average.push_back(P[1]);
		
		epics2017_compt_ratioMax.push_back(P[2]);
		epics2017_compt_average.push_back(P[3]);
		
		epics2017_phot_ratioMax.push_back(P[4]);
		epics2017_phot_average.push_back(P[5]);
		
		epics2017_rayl_ratioMax.push_back(P[6]);
		epics2017_rayl_average.push_back(P[7]);
		
		epics2017_total_ratioMax.push_back(P[8]);
		epics2017_total_average.push_back(P[9]);		
		
	}

	fin.close();

	
	std::ostringstream ost1;
	ost1 <<"./ratioMax_Average_livermore_final.dat"; //
	std::ifstream fin1(ost1.str().c_str());
	
	for(int i = 0; i<13;i++) // 1612 lines 
	{
		
		fin1 >>P[0]>>P[1]>>P[2]>>P[3]>>P[4]>>P[5]>>P[6]>>P[7]>>P[8]>>P[9];
		
		
		
		livermore_pair_ratioMax.push_back(P[0]);
		livermore_pair_average.push_back(P[1]);
		
		livermore_compt_ratioMax.push_back(P[2]);
		livermore_compt_average.push_back(P[3]);
		
		livermore_phot_ratioMax.push_back(P[4]);
		livermore_phot_average.push_back(P[5]);
		
		livermore_rayl_ratioMax.push_back(P[6]);
		livermore_rayl_average.push_back(P[7]);	
		
		livermore_total_ratioMax.push_back(P[8]);
		livermore_total_average.push_back(P[9]);		
		
	}

	fin1.close();
	
	// for(int i = 0; i<13;i++)
	// {
		// printf("Z = %.9e %.9e %.9e %.9e %.9e\n", Z[i],epics2017_total_ratioMax[i],livermore_total_ratioMax[i],epics2017_total_average[i],livermore_total_average[i] );
	// }
	
	// plot_comparison(Z,epics2017_pair_ratioMax,livermore_pair_ratioMax, epics2017_pair_average,livermore_pair_average, Processes[0]);
	// plot_comparison(Z,epics2017_compt_ratioMax,livermore_compt_ratioMax, epics2017_compt_average,livermore_compt_average, Processes[1]);
	// plot_comparison(Z,epics2017_phot_ratioMax,livermore_phot_ratioMax, epics2017_phot_average,livermore_phot_average, Processes[2]);
	// plot_comparison(Z,epics2017_rayl_ratioMax,livermore_rayl_ratioMax, epics2017_rayl_average,livermore_rayl_average, Processes[3]);
	// plot_comparison(Z,epics2017_total_ratioMax,livermore_total_ratioMax, epics2017_total_average,livermore_total_average, Processes[4]);

	plot_comparison_publication(Z,epics2017_pair_ratioMax,livermore_pair_ratioMax, epics2017_pair_average,livermore_pair_average, Processes[0]);
	plot_comparison_publication(Z,epics2017_compt_ratioMax,livermore_compt_ratioMax, epics2017_compt_average,livermore_compt_average, Processes[1]);
	plot_comparison_publication(Z,epics2017_phot_ratioMax,livermore_phot_ratioMax, epics2017_phot_average,livermore_phot_average, Processes[2]);
	plot_comparison_publication(Z,epics2017_rayl_ratioMax,livermore_rayl_ratioMax, epics2017_rayl_average,livermore_rayl_average, Processes[3]);
	plot_comparison_publication(Z,epics2017_total_ratioMax,livermore_total_ratioMax, epics2017_total_average,livermore_total_average, Processes[4]);




}